@@ -5,7 +5,8 @@ from django.core.management.base import BaseCommand
 from openlxp_notifications.management.utils.notification import \
     send_notifications, send_notifications_with_msg
 from openlxp_notifications.models import (ReceiverEmailConfiguration,
-                                          SenderEmailConfiguration)
+                                          SenderEmailConfiguration,
+                                          EmailConfiguration)
 
 logger = logging.getLogger('dict_config_logger')
 
@@ -22,7 +23,13 @@ def send_log_email():
     # Getting sender email id
     sender_email_configuration = SenderEmailConfiguration.objects.first()
     sender = sender_email_configuration.sender_email_address
-    send_notifications(email, sender)
+
+    email_configuration = EmailConfiguration.objects.values(
+        'SUBJECT',
+        'HTML_File',
+        'LOG_PATH')
+
+    send_notifications(email, sender, email_configuration)
 
 
 def send_log_email_with_msg(email, sender, msg):
